@@ -175,6 +175,42 @@ plt.show()
 im = Image.open('../images/ModalNet-19.png')
 im.show()
 
+import numpy as np
+import torch
+import torch.nn as nn
+class ScaledDotProductAttention(nn.Module):
+    """Scaled Dot-Product Attention"""
+    def __init__(self, d_k):
+        super(ScaledDotProductAttention,self).__init__()
+        self.d_k = d_k
+
+    def forward(self, q, k, v, mask=None):
+        '''
+        Inputs:
+        * q: (B, T_q, d_k)
+        * k: (B, T_k, d_k)
+        * v: (B, T_v, d_v) //
+        T_k = T_v
+        -------------------------------
+        Outputs:
+        * output: (B, T_q,
+        d_v)
+        * attn: (B, T_q, T_k)
+        '''
+        assert q.size(2) == k.size(2), "keys &quries must have same dimension"
+        assert k.size(1) == v.size(1), "T_k =T_v"
+        scores = torch.bmm(q, k.transpose(1, 2)) # (B, T_q, d_k) * (B, d_k,T_k) -> (B, T_q, T_k)
+        scores = scores / np.sqrt(self.d_k)
+        if mask is not None:
+            scores = scores.masked_fill(mask, -np.inf)
+
+        attn = torch.softmax(scores, dim=-1) # (B, T_q, T_k) --> (B, T_q, T_k)
+        # fill all nan to zero
+        mask_nan = torch.isnan(attn)
+        attn = attn.masked_fill(mask_nan, 0)
+        output = torch.bmm(attn, v) # (B, T_q, T_k) * (B, T_v, d_v) --> (B, T_q, d_v), make sure that T_k == T_v
+        return output, attn
+
 ''''
 An attention function can be described as mapping a query and a set of key-value pairs to an output, 
 where the query, keys, values, and output are all vectors. 
