@@ -120,7 +120,7 @@ class NamedEntityRecognitionDataset(Dataset):
         return list_of_source_no, list_of_source_str, list_of_target_str
 
 
-from gluonnlp.data import SentencepieceTokenizer, SentencepieceDetokenizer
+#from gluonnlp.data import SentencepieceTokenizer, SentencepieceDetokenizer
 from yonlu.kobert.pytorch_kobert import get_pytorch_kobert_model
 from yonlu.kobert.utils import get_tokenizer
 from yonlu.data_utils.vocab_tokenizer import Vocabulary, Tokenizer
