@@ -2,7 +2,7 @@
 from yonlu.word_embeddings.word_embeddings import Word2Vec
 
 word2vec = Word2Vec()
-mode = 'simple'
+mode = 'unfiltered'
 mecab_path = 'C:\\mecab\\mecab-ko-dic'
 stopword_file = '../stopwords/stopwordsKor.txt'
 files = []
@@ -10,16 +10,17 @@ files.append('../data/content.txt')
 is_directory=False
 doc_index=-1
 max=-1
-word2vec.preprocessing(mode,mecab_path,stopword_file,files,is_directory,doc_index,max)
+is_mecab=False
+word2vec.preprocessing(mode,is_mecab,mecab_path,stopword_file,files,is_directory,doc_index,max)
 
 min_count=1
 window=5
 size=200
-negative=5
+negative=0
 word2vec.train(min_count, window, size, negative)
 
-model_file = 'word2vec.txt'
-binary=False;
+model_file = 'word2vec_1.bin'
+binary=True;
 word2vec.save_model(model_file, binary)
 
 
