@@ -15,17 +15,25 @@ class WordEmbeddings:
     def __init__(self):
         self.documents = []
 
-    def preprocessing(self, mode, path, stopword_file, files, is_directory=False, doc_index=-1, max=-1):
+    def preprocessing(self, mode, is_mecab, path, stopword_file, files,
+                      is_directory=False, doc_index=-1, max=-1):
         util = ptm.Utility()
         # mode is either filtered or unfiltered or simple
         corpus = []
         if mode == 'unfiltered':
             # path = '/usr/local/lib/mecab/dic/mecab-ko-dic'
-            pipeline = ptm.Pipeline(ptm.splitter.KoSentSplitter(),
-                                    ptm.tokenizer.Komoran(),
-                                    ptm.lemmatizer.SejongPOSLemmatizer(),
-                                    ptm.helper.SelectWordOnly(),
-                                    ptm.helper.StopwordFilter(file=stopword_file))
+            if not is_mecab:
+                pipeline = ptm.Pipeline(ptm.splitter.NLTK(),
+                                        ptm.tokenizer.Komoran(),
+                                        ptm.lemmatizer.SejongPOSLemmatizer(),
+                                        ptm.helper.SelectWordOnly(),
+                                        ptm.helper.StopwordFilter(file=stopword_file))
+            else:
+                pipeline = ptm.Pipeline(ptm.splitter.NLTK(),
+                                        ptm.tokenizer.MeCab(path),
+                                        ptm.lemmatizer.SejongPOSLemmatizer(),
+                                        ptm.helper.SelectWordOnly(),
+                                        ptm.helper.StopwordFilter(file=stopword_file))
 
             for a_file in files:
                 if is_directory == True and max == -1:
@@ -33,7 +41,8 @@ class WordEmbeddings:
                 elif is_directory == False and doc_index != -1 and max == -1:
                     corpus += ptm.CorpusFromFieldDelimitedFile(a_file, doc_index).docs
                 elif is_directory == False and doc_index == -1 and max == -1:
-                    corpus += ptm.CorpusFromFile(a_file).docs
+                    encoding='euc-kr'
+                    corpus += ptm.CorpusFromFile(a_file, encoding=encoding).docs
                 elif is_directory == False and max > 0:
                     count = 0
                     docs = []
@@ -207,6 +216,8 @@ class WordEmbeddings:
                                             sample=6e-5,
                                             alpha=0.03,
                                             min_alpha=0.0007,
+                                            sg=1,
+
                                             negative=negative,
                                             workers=cores - 1)
 
@@ -234,8 +245,8 @@ class Word2Vec(WordEmbeddings):
         print('Word2Vec')
         super().__init__()
 
-    def preprocessing(self, mode, mecab_path, stopword_file, files, is_directory=False, doc_index=-1, max=-1):
-        super().preprocessing(mode, mecab_path, stopword_file, files, is_directory, doc_index, max)
+    def preprocessing(self, mode, is_mecab, mecab_path, stopword_file, files, is_directory=False, doc_index=-1, max=-1):
+        super().preprocessing(mode, is_mecab, mecab_path, stopword_file, files, is_directory, doc_index, max)
 
     def train(self, min_count=5, window=5, size=300, negative=20):
         super().train(min_count, window, size, negative)
@@ -259,7 +270,7 @@ class FastText(WordEmbeddings):
         print('FastText')
         super().__init__()
 
-    def preprocessing(self, mode, mecab_path, stopword_file, files, is_directory=False, doc_index=-1, max=-1):
+    def preprocessing(self, mode, is_mecab, mecab_path, stopword_file, files, is_directory=False, doc_index=-1, max=-1):
         super().preprocessing(mode, mecab_path, stopword_file, files, is_directory, doc_index, max)
 
     def train(self, min_count=5, window=5, size=300, negative=20, sg=0, min_n=2, max_n=6):
